from setuptools import setup

setup(
    name="betby",
    version="0.3.49",
    author="Ayrat Badrutdinov",
    author_email="a.badrutdinov@betby.com",
    description="Betby libraries",
    packages=["betby"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)
